# TRANO

<div style="padding: 10px; border: 1px solid #f0ad4e; border-radius: 5px; background-color: #fef7e6;">
  <strong>⚠️ Documentation:</strong> <a href="https://andoludo.github.io/trano/" target="_blank">trano</a>
</div>

Trano is a package designed to automate the implementation of building energy simulation models using a simplified YAML input format. It leverages existing validated Modelica libraries, including the [Buildings library](https://simulationresearch.lbl.gov/modelica/) and the [IDEAS library](https://github.com/open-ideas/IDEAS), as well as other Modelica libraries.
